from django.test import TestCase
from suit.menu import ParentItem


class TestMenuTestCase(TestCase):
    def setUp(self):
        pass

    def test_method(self):
        """
        Just a dummy test case to satisfy Travis until all the tests are finished
        """
        self.assertEqual(ParentItem(app='abc')._key(), 'abc')




from suit.apps import DjangoSuitConfig

from django.conf import settings


class SuitConfig(DjangoSuitConfig):

    menu = getattr(settings, 'ADMIN_MENU', [])

    layout = getattr(settings, 'ADMIN_LAYOUT', 'vertical')




from django.template.loader import render_to_string


def short_description(description):

    def decorator(f):

        def wrap(*args, **kwargs):
            return f(*args, **kwargs)

        wrap.short_description = description
        wrap.__name__ = f.__name__

        return wrap

    return decorator


def template_list_item(template_name, description=None):

    def decorator(f):

        def wrap(*args, **kwargs):
            return render_to_string(template_name, f(*args, **kwargs))

        if description is not None:
            wrap.short_description = description

        return wrap

    return decorator




from django.urls import path
from django.contrib import admin
from django.conf import settings
from django.conf.urls.i18n import i18n_patterns


if hasattr(settings, 'SITE_HEADER'):
    admin.site.site_header = settings.SITE_HEADER

admin.autodiscover()


app_urls = i18n_patterns(

    path('admin/', admin.site.urls)

)
